@@ -6,7 +6,10 @@ import logging
 import os
 
 
-XSAN_TEST_CONFIGS_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'test_data/test_xsan_configs')
+XSAN_TEST_CONFIGS_DIR = os.path.join(
+    os.path.dirname(os.path.abspath(__file__)),
+    'test_data/test_xsan_configs'
+)
 LOGGER = logging.getLogger(__name__)
 LOG_FORMAT = ('%(levelname) -10s %(asctime)s %(name) -30s %(funcName) '
               '-35s %(lineno) -5d: %(message)s')
@@ -27,7 +30,10 @@ class check_xsan_config_parsing(unittest.TestCase):
             elif releaseVersion == 11:
                 self.assertEqual(function_result, '/Library/Preferences/Xsan/')
             elif releaseVersion == 10:
-                self.assertEqual(function_result, '/Library/Filesystems/Xsan/config/')
+                self.assertEqual(
+                    function_result,
+                    '/Library/Filesystems/Xsan/config/'
+                )
             else:
                 self.fail(msg='Not running on supported OS X release')
         else:
@@ -57,7 +63,10 @@ class check_xsan_config_parsing(unittest.TestCase):
             'NotAVolume',
         ]
 
-        LOGGER.info("xsan_volume objects in DB: %s", models.xsan_volume.objects.all())
+        LOGGER.info(
+            "xsan_volume objects in DB: %s",
+            models.xsan_volume.objects.all()
+        )
 
         #   Should put all real volumes into DB
         for expected_volume in expected_found_volumes:
@@ -70,7 +79,7 @@ class check_xsan_config_parsing(unittest.TestCase):
         #   Shouldn't put the fake volume config in DB
         for unexpected_found_volume in unexpected_found_volumes:
             vol_object = models.xsan_volume.objects.filter(
-                name = unexpected_found_volume,
+                name=unexpected_found_volume,
             ).all()
 
             self.assertFalse(vol_object)
@@ -115,7 +124,8 @@ class check_xsan_config_parsing(unittest.TestCase):
             for lun_name in volume_luns[volume_name]:
                 lun_object = models.xsan_volume_lun.objects.filter(
                     label=lun_name,
-                    volume=models.xsan_volume.objects.filter(name=volume_name).all()[0],
+                    volume=models.xsan_volume.objects.filter(
+                        name=volume_name).all()[0],
                 ).all()
 
                 self.assertTrue(lun_object)
@@ -166,6 +176,7 @@ class check_xsan_config_parsing(unittest.TestCase):
 
             self.assertEqual(client_obj.ip_address, expected_ip_addr)
 
+
 class check_xsan_client_interactions(unittest.TestCase):
     """Check that we can properly interact with clients.
     Mostly checks that parser is sane
@@ -203,21 +214,21 @@ class check_xsan_client_interactions(unittest.TestCase):
                 'ActiveVideo10',
                 'ActiveVideo11',
                 'ActiveVideo12',
-                ],
+            ],
             'DailyVideo': [
                 'Arena25_DailyVideoMD',
                 'Arena25_DailyVideoData1',
                 'Arena26_DailyVideoData2',
                 'Arena27_DailyVideoData3',
                 'Arena28_DailyVideoData4',
-                ],
+            ],
             'VENUS': [
                 'XsanMeta184',
                 'XsanData181',
                 'XsanData182',
                 'XsanData183',
                 'XsanData184',
-                ],
+            ],
         }
 
         #   Populate the database with all the stuff
@@ -238,12 +249,14 @@ class check_xsan_client_interactions(unittest.TestCase):
             for test_lun_name in volume_luns[test_volume_name]:
                 test_lun = models.xsan_volume_lun(
                     label=test_lun_name,
-                    volume=models.xsan_volume.objects.filter(name=test_volume_name).all()[0],
+                    volume=models.xsan_volume.objects.filter(
+                        name=test_volume_name,
+                    ).all()[0],
                 )
                 test_lun.save()
 
         #   Also some cvlabel data needs to be added
-        for i in range(1,4):
+        for i in range(1, 4):
             test_client = models.xsanio_client.objects.get(pk=i)
             test_client_volume = models.xsan_volume.objects.get(pk=i)
 
@@ -268,66 +281,153 @@ class check_xsan_client_interactions(unittest.TestCase):
         self.add_test_data()
 
         test_iodata = [
-            {"cvlabel":
-                 {
-                     "disk8": "XsanMetaSmall184",
-                     "disk0": "XsanData184",
-                     "disk1": "XsanData182",
-                     "disk2": "XsanData181",
-                     "disk3": "XsanData183",
-                     "disk7": "XsanSmall184"
-                 },
-             "sample_time": 2.0,
-             "iodata":
-                 {
-                     "disk8": {"bytes_read_sec": 10.0, "io_read_sec": 10.0, "bytes_write_sec": 100.0, "io_write_sec": 1.0},
-                     "disk0": {"bytes_read_sec": 20.0, "io_read_sec": 20.0, "bytes_write_sec": 200.0, "io_write_sec": 2.0},
-                     "disk1": {"bytes_read_sec": 30.0, "io_read_sec": 30.0, "bytes_write_sec": 300.0, "io_write_sec": 3.0},
-                     "disk2": {"bytes_read_sec": 40.0, "io_read_sec": 40.0, "bytes_write_sec": 400.0, "io_write_sec": 4.0},
-                     "disk3": {"bytes_read_sec": 50.0, "io_read_sec": 50.0, "bytes_write_sec": 500.0, "io_write_sec": 5.0},
-                     "disk4": {"bytes_read_sec": 60.0, "io_read_sec": 60.0, "bytes_write_sec": 600.0, "io_write_sec": 6.0},
-                     "disk5": {"bytes_read_sec": 70.0, "io_read_sec": 70.0, "bytes_write_sec": 700.0, "io_write_sec": 7.0},
-                     "disk7": {"bytes_read_sec": 80.0, "io_read_sec": 80.0, "bytes_write_sec": 800.0, "io_write_sec": 8.0}
-                 }
+            {
+                "cvlabel": {
+                    "disk8": "XsanMetaSmall184",
+                    "disk0": "XsanData184",
+                    "disk1": "XsanData182",
+                    "disk2": "XsanData181",
+                    "disk3": "XsanData183",
+                    "disk7": "XsanSmall184"
+                },
+                "sample_time": 2.0,
+                "iodata": {
+                    "disk8": {
+                        "bytes_read_sec": 10.0,
+                        "io_read_sec": 10.0,
+                        "bytes_write_sec": 100.0,
+                        "io_write_sec": 1.0
+                    },
+                    "disk0": {
+                        "bytes_read_sec": 20.0,
+                        "io_read_sec": 20.0,
+                        "bytes_write_sec": 200.0,
+                        "io_write_sec": 2.0
+                    },
+                    "disk1": {
+                        "bytes_read_sec": 30.0,
+                        "io_read_sec": 30.0,
+                        "bytes_write_sec": 300.0,
+                        "io_write_sec": 3.0
+                    },
+                    "disk2": {
+                        "bytes_read_sec": 40.0,
+                        "io_read_sec": 40.0,
+                        "bytes_write_sec": 400.0,
+                        "io_write_sec": 4.0
+                    },
+                    "disk3": {
+                        "bytes_read_sec": 50.0,
+                        "io_read_sec": 50.0,
+                        "bytes_write_sec": 500.0,
+                        "io_write_sec": 5.0
+                    },
+                    "disk4": {
+                        "bytes_read_sec": 60.0,
+                        "io_read_sec": 60.0,
+                        "bytes_write_sec": 600.0,
+                        "io_write_sec": 6.0
+                    },
+                    "disk5": {
+                        "bytes_read_sec": 70.0,
+                        "io_read_sec": 70.0,
+                        "bytes_write_sec": 700.0,
+                        "io_write_sec": 7.0
+                    },
+                    "disk7": {
+                        "bytes_read_sec": 80.0,
+                        "io_read_sec": 80.0,
+                        "bytes_write_sec": 800.0,
+                        "io_write_sec": 8.0
+                    },
+                }
             },
-            {"cvlabel":
-                 {
-                     "disk8": "ActiveMD",
-                     "disk0": "ActiveVideo01",
-                     "disk1": "ActiveVideo02",
-                     "disk2": "ActiveVideo03",
-                     "disk4": "ActiveVideo04",
-                     "disk5": "ActiveVideo05",
-                 },
-             "sample_time": 2.0,
-             "iodata":
-                 {
-                     "disk8": {"bytes_read_sec": 10.0, "io_read_sec": 10.0, "bytes_write_sec": 100.0, "io_write_sec": 1.0},
-                     "disk0": {"bytes_read_sec": 20.0, "io_read_sec": 20.0, "bytes_write_sec": 200.0, "io_write_sec": 2.0},
-                     "disk1": {"bytes_read_sec": 30.0, "io_read_sec": 30.0, "bytes_write_sec": 300.0, "io_write_sec": 3.0},
-                     "disk2": {"bytes_read_sec": 40.0, "io_read_sec": 40.0, "bytes_write_sec": 400.0, "io_write_sec": 4.0},
-                     "disk3": {"bytes_read_sec": 50.0, "io_read_sec": 50.0, "bytes_write_sec": 500.0, "io_write_sec": 5.0},
-                     "disk4": {"bytes_read_sec": 60.0, "io_read_sec": 60.0, "bytes_write_sec": 600.0, "io_write_sec": 6.0},
-                     "disk5": {"bytes_read_sec": 70.0, "io_read_sec": 70.0, "bytes_write_sec": 700.0, "io_write_sec": 7.0},
-                     "disk7": {"bytes_read_sec": 80.0, "io_read_sec": 80.0, "bytes_write_sec": 800.0, "io_write_sec": 8.0}
-                 }
+            {
+                "cvlabel": {
+                    "disk8": "ActiveMD",
+                    "disk0": "ActiveVideo01",
+                    "disk1": "ActiveVideo02",
+                    "disk2": "ActiveVideo03",
+                    "disk4": "ActiveVideo04",
+                    "disk5": "ActiveVideo05",
+                },
+                "sample_time": 2.0,
+                "iodata": {
+                    "disk8": {
+                        "bytes_read_sec": 10.0,
+                        "io_read_sec": 10.0,
+                        "bytes_write_sec": 100.0,
+                        "io_write_sec": 1.0
+                    },
+                    "disk0": {
+                        "bytes_read_sec": 20.0,
+                        "io_read_sec": 20.0,
+                        "bytes_write_sec": 200.0,
+                        "io_write_sec": 2.0
+                    },
+                    "disk1": {
+                        "bytes_read_sec": 30.0,
+                        "io_read_sec": 30.0,
+                        "bytes_write_sec": 300.0,
+                        "io_write_sec": 3.0
+                    },
+                    "disk2": {
+                        "bytes_read_sec": 40.0,
+                        "io_read_sec": 40.0,
+                        "bytes_write_sec": 400.0,
+                        "io_write_sec": 4.0
+                    },
+                    "disk3": {
+                        "bytes_read_sec": 50.0,
+                        "io_read_sec": 50.0,
+                        "bytes_write_sec": 500.0,
+                        "io_write_sec": 5.0
+                    },
+                    "disk4": {
+                        "bytes_read_sec": 60.0,
+                        "io_read_sec": 60.0,
+                        "bytes_write_sec": 600.0,
+                        "io_write_sec": 6.0
+                    },
+                    "disk5": {
+                        "bytes_read_sec": 70.0,
+                        "io_read_sec": 70.0,
+                        "bytes_write_sec": 700.0,
+                        "io_write_sec": 7.0
+                    },
+                    "disk7": {
+                        "bytes_read_sec": 80.0,
+                        "io_read_sec": 80.0,
+                        "bytes_write_sec": 800.0,
+                        "io_write_sec": 8.0,
+                    },
+                }
             },
         ]
 
 #        for test_client in models.xsanio_client.objects.all():
         for i in range(1, len(test_iodata) + 1):
-            LOGGER.info("cvalbel_entry dump:\n%s", models.cvlabel_entry.objects.all())
+            LOGGER.info(
+                "cvalbel_entry dump:\n%s",
+                models.cvlabel_entry.objects.all()
+            )
             test_client = models.xsanio_client.objects.get(pk=i)
-            xsanio_backend.parse_client_io_data(test_client, test_iodata[i-1])
+            xsanio_backend.parse_client_io_data(
+                test_client,
+                test_iodata[i - 1]
+            )
 
-            #   Now we ensure that all corresponding stat_entry objects were created
-            test_client_disk_iodata = test_iodata[i-1]['iodata']
+            #   Now we ensure that all corresponding
+            #   stat_entry objects were created
+            test_client_disk_iodata = test_iodata[i - 1]['iodata']
             for disk_name in test_client_disk_iodata:
                 iodata = test_client_disk_iodata[disk_name]
 
                 for stat_type_name in iodata:
                     expected_value = iodata[stat_type_name]
-                    stat_type = models.stat_type.objects.filter(name=stat_type_name).all()[0]
+                    stat_type = models.stat_type.objects.filter(
+                        name=stat_type_name
+                    ).all()[0]
 
                     value_in_db = models.stat_entry.objects.filter(
                         type=stat_type,
@@ -335,11 +435,15 @@ class check_xsan_client_interactions(unittest.TestCase):
                         disk=disk_name,
                     ).all()[0].value
 
-                    LOGGER.info("Checking stat entry for %s: %s", test_client, stat_type_name)
+                    LOGGER.info(
+                        "Checking stat entry for %s: %s",
+                        test_client,
+                        stat_type_name
+                    )
                     self.assertEqual(expected_value, value_in_db)
 
             #   Check cvlabel objects too
-            test_client_cvlabel_data = test_iodata[i-1]['cvlabel']
+            test_client_cvlabel_data = test_iodata[i - 1]['cvlabel']
             for disk_name in test_client_cvlabel_data:
                 label_name = test_client_cvlabel_data[disk_name]
 
@@ -348,7 +452,9 @@ class check_xsan_client_interactions(unittest.TestCase):
                     disk=disk_name,
                 ).all()[0]
 
-                LOGGER.info("Checking cvlabel for %s: %s", test_client, disk_name)
+                LOGGER.info(
+                    "Checking cvlabel for %s: %s",
+                    test_client,
+                    disk_name
+                )
                 self.assertEqual(label_name, cvlabel_entry.label)
-
-
