@@ -36,8 +36,7 @@ class process_launcher():
         self.PROCESSES.append(process)
 
     def run(self):
-        for process in self.PROCESSES:
-            process.start()
+        map(lambda x: x.start(), self.PROCESSES)
 
         while True:
             #   Check if all processes are alive
@@ -94,7 +93,8 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
         1) List of volumes on MDC
         2) List of LUNs that each volume consists of
 
-    This data is then added to the database (models are xsan_volume and xsan_volume_lun)
+    This data is then added to the database
+    (models are xsan_volume and xsan_volume_lun)
 
     """
     if os.path.isdir(xsan_config_path):
@@ -107,8 +107,10 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
 
         for config_file_name in config_file_list:
             #   We'll add the volume only if it looks like a real volume config
-            #   We consider it a volume config, if any line there matches config_node_regex
-            #   If any line matched, we change is_a_volume config to True and add a new record to DB model xsan_volume
+            #   We consider it a volume config,
+            #   if any line there matches config_node_regex
+            #   If any line matched, we change is_a_volume config
+            #   to True and add a new record to DB model xsan_volume
             is_a_volume_config = False
 
             if re.match(xsan_config_regex, config_file_name):
@@ -120,7 +122,10 @@ def update_volume_list(xsan_config_path, xsan_config_regex, config_node_regex):
                 )
 
                 if re.match(xsan_config_regex, config_file_name):
-                    config_file_path = os.path.join(xsan_config_path, config_file_name)
+                    config_file_path = os.path.join(
+                        xsan_config_path,
+                        config_file_name
+                    )
                     config_file = open(config_file_path, 'r')
 
                     for line in config_file:
@@ -162,8 +167,10 @@ def client_ping_response(client):
 
 
 def parse_client_io_data(client, io_data):
-    """Gotta be careful here, since there should be only one stat entry for each status entry type for each host
-    Basically, this function parses client HTTP response and creates stat_entry objects in DB
+    """Gotta be careful here, since there should be only one stat entry
+    for each status entry type for each host
+    Basically, this function parses client HTTP response and creates
+    stat_entry objects in DB
 
     """
     #   Getting the cvlabel data
@@ -183,7 +190,8 @@ def parse_client_io_data(client, io_data):
         for cvlabel in cvlabels:
             disk_name = cvlabel
             cvlabel_name = cvlabels[cvlabel]
-            #   So, we either update existing cvlabel entry or create a new one
+            #   So, we either update existing cvlabel entry or create
+            #   a new one
             cvlabel_obj = models.cvlabel_entry.objects.filter(
                 host=client,
                 disk=disk_name,
@@ -203,10 +211,15 @@ def parse_client_io_data(client, io_data):
                 )
                 new_cvlabel_obj.save()
             else:
-                LOGGER.critical('Two cvlabel entries for one disk found. Something is TERRIBLY wrong!')
+                LOGGER.critical(
+                    'Two cvlabel entries for one disk found.'
+                )
                 sys.exit()
     else:
-        LOGGER.error('Response from client %s doesn\'t contain cvlabel data', client.host_name)
+        LOGGER.error(
+            'Response from client %s doesn\'t contain cvlabel data',
+            client.host_name
+        )
 
     #   Getting the disk data
     if 'iodata' in io_data:
@@ -225,8 +238,10 @@ def parse_client_io_data(client, io_data):
             disk_iodata = disks[disk_name]
 
             #   Adding a couple of auto-calculated stats
-            disk_iodata['io_sec'] = disk_iodata['io_read_sec'] + disk_iodata['io_write_sec']
-            disk_iodata['bytes_sec'] = disk_iodata['bytes_read_sec'] + disk_iodata['bytes_write_sec']
+            disk_iodata['io_sec'] = disk_iodata['io_read_sec'] + \
+                disk_iodata['io_write_sec']
+            disk_iodata['bytes_sec'] = disk_iodata['bytes_read_sec'] + \
+                disk_iodata['bytes_write_sec']
 
             for stat in disk_iodata:
                 #   Does an entry already exist?
@@ -254,14 +269,18 @@ def parse_client_io_data(client, io_data):
                     )
                     new_stat_entry.save()
                 else:
-                    LOGGER.critical('Two stat entries for one host found! This is TERRIBLY wrong!')
+                    LOGGER.critical('Two stat entries for one host found!')
                     sys.exit()
     else:
-        LOGGER.error('Response from client %s does not contain disk I/O statistics', client.host_name)
+        LOGGER.error(
+            'Response from client %s does not contain disk I/O statistics',
+            client.host_name
+        )
 
 
 def get_stats_from_client(client, update_interval):
-    """Shoots the HTTP request. Gets response body and calls parse_client_io_data
+    """Shoots the HTTP request. Gets response body and
+    calls parse_client_io_data
 
     """
     while True:
@@ -273,11 +292,18 @@ def get_stats_from_client(client, update_interval):
             client.is_unreachable = False
             try:
                 LOGGER.info('Requesting stats from %s', client.host_name)
-                http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
+                http_conn = httplib.HTTPConnection(
+                    host=client.ip_address,
+                    port=client.port,
+                    timeout=3
+                )
                 http_conn.request('GET', '/')
                 http_response = http_conn.getresponse()
             except:
-                LOGGER.info('Client %s does not have xsanio_client installed', client.host_name)
+                LOGGER.info(
+                    'Client %s does not have xsanio_client installed',
+                    client.host_name
+                )
                 client.has_client_installed = False
                 client.save()
                 time.sleep(update_interval)
@@ -289,12 +315,23 @@ def get_stats_from_client(client, update_interval):
                 host_response_data = http_response.read()
                 io_data = json.loads(host_response_data)
                 parse_client_io_data(client, io_data)
-                LOGGER.info('Finished parsing response from %s', client.host_name)
+                LOGGER.info(
+                    'Finished parsing response from %s',
+                    client.host_name
+                )
             else:
-                LOGGER.info("Client %s responded with %s", client.host_name, http_response.status)
+                LOGGER.info(
+                    "Client %s responded with %s",
+                    client.host_name,
+                    http_response.status
+                )
         else:
             client.is_unreachable = True
-            LOGGER.info('Client %s responded to ping with %s', client.host_name, ping_resp)
+            LOGGER.info(
+                'Client %s responded to ping with %s',
+                client.host_name,
+                ping_resp
+            )
             client.save()
 
         time.sleep(update_interval)
@@ -386,9 +423,12 @@ def main():
     logging.basicConfig(level=LOG_LEVEL, format=LOG_FORMAT)
 
     XSAN_CONFIG_DIR = get_xsan_config_dir()
-    update_volume_list(XSAN_CONFIG_DIR, XSAN_VOLUME_CONFIG_REGEX, XSAN_CONFIG_NODE_REGEX)
+    update_volume_list(
+        XSAN_CONFIG_DIR,
+        XSAN_VOLUME_CONFIG_REGEX,
+        XSAN_CONFIG_NODE_REGEX
+    )
 
     discover_clients(XSAN_CONFIG_DIR)
 
     update_clients()
-
