@@ -85,8 +85,13 @@ class display_volume_detail(DetailView):
         for client_data in all_clients_data:
             for stat_type in client_data:
                 stat_value = client_data[stat_type]
-                global_stats[stat_type] = (global_stats.get(stat_type, 0.0) +
-                    stat_value)
+                #   Probably not the best way to do this...
+                try:
+                    global_stats[stat_type] = (global_stats.get(stat_type, 0.0) +
+                        stat_value)
+                except TypeError:
+                    #   This isn't a float, so screw it
+                    pass
 
         #   Remove clients that don't have all stats defined
         #   TODO: find a better way to resolve this!
